pyxmpp2.session

Package pyxmpp2 :: Module session |
[hide private]

# Module session

IM Session establishement implementation.

This module provides a stream feature handler to implement the IM session establishment request defined in RFC 3921, but dropped in RFC 6120. The implementation is needed for backward compatibility.

Normative reference:
  - RFC 3921
  - RFC 6120 (Appendix E. states it should be no-op now, when implemented on server side)

Classes | [hide private]
| SessionHandler RFC 3921 session establishment implementation.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.session")`
| SESSION_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-session}session``'``